// Copyright (c) 2023 Tudor Stanciu

import axios, { AxiosHeaders } from "axios";
import { fetch } from "../state";

function getHeaders(): AxiosHeaders {
  const { token } = fetch();
  const headers = new AxiosHeaders({
    "Content-Type": "application/json"
  });
  if (token) {
    headers.Authorization = `Tuitio ${token}`;
  }
  return headers;
}

async function request(url: string, method: string) {
  const headers = getHeaders();
  try {
    const res = await axios.request({ url, method, headers });
    return res.data;
  } catch (error: any) {
    if (error.response && error.response.data) {
      const { detail, title } = error.response.data;
      throw {
        ...error.response.data,
        message: detail || title
      };
    }
    throw error;
  }
}

export { request };
